# PeerReviewGroupV20

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**last_modified_date** | [**LastModifiedDateV20**](LastModifiedDateV20.md) |  | [optional] 
**external_ids** | [**ExternalIDsV20**](ExternalIDsV20.md) |  | [optional] 
**peer_review_summary** | [**list[PeerReviewSummaryV20]**](PeerReviewSummaryV20.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

